% Example Script for MYAXISC showing all methods and their usage
clear variables

% Use Figure 1 and clear all content
figure(1)
clf;

% Create empty axis system with 4 y axis by calling:
% handle = maxis(number of axis, y-spacing between outside lines)
h = myaxisc(4,0.10,[0.1,0.1,0.8,0.8]); % Specify position
% h = myaxisc(4,0.1); % Use Default Matlab positions

% Create some random data for plotting
t = 0:0.1:5;
y1 = sin(t);
y21 = t.^2-5;
t22 = 0:1:5;
y22 = 15-t22.*2;
y3 = sqrt(t).*2+97;
y41 = rand(size(t))-2;
y42 = rand(size(t))+4;

% Call plot and specify y-axis number using method h.p(nr). For creating a
% legend later, we need to assign the handles returned by plot to p.
p(1) = plot(h.p(1),t,y1,'Color',[0,0,1]);
p(2) = plot(h.p(2),t,y21,'Color',[0,0.5,0]);
p(3) = plot(h.p(2),t22,y22,'Color',[0,0.5,0],'LineStyle','--','Marker','o');
p(4) = plot(h.p(3),t,y3,'r');
p(5) = plot(h.p(4),t,y41,'Color',[0.8,0.4,0]);
p(6) = plot(h.p(4),t,y42,'Color',[0.3,0.3,0.3]);

% Unfortunately, scaling needs to be triggered manually after plotting:
h.xlim([0,5]); % Set X-Axis Limits
h.autoscale % Automatically Scale Y Axis

% Additional methods to modify appearance, scaling and so on:

h.autoy(3) % Autoscale only specified y-axis
h.ylim(3,[95,105]); % Set Y-Limits for axis 3
h.ylim(4,[-3,8]); % Set Y-Limits for axis 4

h.gridon % Enable grid (use h.gridoff to remove)

% Modify the y-Axis Color
h.ycolor(1,[0,0,1]);
h.ycolor(2,[0,0.5,0]);
h.ycolor(3,'r');
h.ycolor(4,[1,0.5,0]);

% Add y-Labels
h.ylabel(1,'First Y-Axis (Y1)');
h.ylabel(2,'Second Y-Axis (Y2)');
h.ylabel(3,'Third Y-Axis (Y3)');
h.ylabel(4,'Another Y-Axis(Y4)');

% Add x-Label
h.xlabel('X-Axis');

% Change Position of the whole myaxisc-Object
h.position([0.1,0.1,0.8,0.8],0.12); % Position-Vector and Spacing 0.12

% Change all font sizes
h.fontsize(9)

% Adding a Legend: A separate target h.legendtarget for the legend as well
% as an vector "p" containing all handles to plot lines need to be
% specified.
legend(h.legendtarget,p,...
    'Line 1','Line 2','Line 3','Line 4','Line 5','Line 6');